@@ -5,7 +5,7 @@ import os
 from pathlib import Path
 
 # Load credentials and server information from YAML file
-ROOT =  Path(__file__).parent
+ROOT = os.environ.get('MINDER_DOWNLOADER_HOME', Path(__file__).parent)
 INFO_PATH = f'{ROOT}{os.sep}info.yaml'
 os.environ['MINDER_TOKEN'] = load_yaml(INFO_PATH)['token']
 SERVER = load_yaml(INFO_PATH)['server']
@@ -16,7 +16,19 @@ AUTH = BearerAuth(os.getenv('MINDER_TOKEN'))
 
 
 def _minder_datasets_info() -> pd.DataFrame:
-    """Returns minder research portal datasets."""
+    """
+    Returns a Pandas DataFrame with information about Minder research portal datasets.
+    Parameters:
+    None
+
+    Returns:
+    A Pandas DataFrame with the following columns:
+    - datasets: The name of the dataset.
+    - type: The type of the dataset (e.g., clinical, survey).
+    - description: A brief description of the dataset.
+    - availableColumns: A list of available columns in the dataset.
+    - domain: The domain the dataset belongs to.
+    """
     info_path = SERVER + '/info/datasets'
     request = requests.get(info_path, auth=AUTH)
     domains = request.json()['Categories'].keys()
@@ -31,7 +43,17 @@ def _minder_datasets_info() -> pd.DataFrame:
 
 
 def _minder_organizations_info() -> pd.DataFrame:
-    """Returns minder research portal organizations."""
+    """
+    Returns a Pandas DataFrame with information about Minder research portal organizations.
+    Parameters:
+    None
+
+    Returns:
+    A Pandas DataFrame with the following columns:
+    - organization: The name of the organization.
+    - acronym: The organization's acronym.
+    - description: A brief description of the organization.
+    """    
     info_path = SERVER + '/info/organizations'
     request = requests.get(info_path, auth=AUTH)
     info = pd.DataFrame(request.json()['organizations'])
